PortfolioConfig

Struct PortfolioConfig 

pub struct PortfolioConfig {
    pub use_mark_prices: bool,
    pub use_mark_xrates: bool,
    pub bar_updates: bool,
    pub convert_to_account_base_currency: bool,
    pub min_account_state_logging_interval_ms: Option<u64>,
    pub debug: bool,
}
Configuration for Portfolio instances.

Fields

use_mark_prices: bool

The type of prices used for portfolio calculations, such as unrealized PnLs. If false (default), uses quote prices if available; otherwise, last trade prices (or falls back to bar prices if bar_updates is true). If true, uses mark prices.

use_mark_xrates: bool

The type of exchange rates used for portfolio calculations. If false (default), uses quote prices. If true, uses mark prices.

bar_updates: bool

If external bars should be considered for updating unrealized PnLs.

convert_to_account_base_currency: bool

If calculations should be converted into each account’s base currency. This setting is only effective for accounts with a specified base currency.

min_account_state_logging_interval_ms: Option<u64>

The minimum interval (milliseconds) between logging account state events for the same account. When set, account state updates will only be logged if this much time has passed since the last log. Useful for HFT deployments to prevent excessive logging when account states change rapidly.

debug: bool

If debug mode is active (will provide extra debug logging).

Implementations

Source

impl PortfolioConfig

pub fn builder() -> PortfolioConfigBuilder

Create an instance of PortfolioConfig using the builder syntax