PortfolioConfigBuilder

Struct PortfolioConfigBuilder 

pub struct PortfolioConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> PortfolioConfigBuilder<S>

pub fn build(self) -> PortfolioConfig
where S: IsComplete,

Finish building and return the requested object

pub fn use_mark_prices( self, value: bool, ) -> PortfolioConfigBuilder<SetUseMarkPrices<S>>
where S::UseMarkPrices: IsUnset,

Optional (Some / Option setters). Default: false.

The type of prices used for portfolio calculations, such as unrealized PnLs. If false (default), uses quote prices if available; otherwise, last trade prices (or falls back to bar prices if bar_updates is true). If true, uses mark prices.

pub fn maybe_use_mark_prices( self, value: Option<bool>, ) -> PortfolioConfigBuilder<SetUseMarkPrices<S>>
where S::UseMarkPrices: IsUnset,

Optional (Some / Option setters). Default: false.

The type of prices used for portfolio calculations, such as unrealized PnLs. If false (default), uses quote prices if available; otherwise, last trade prices (or falls back to bar prices if bar_updates is true). If true, uses mark prices.

pub fn use_mark_xrates( self, value: bool, ) -> PortfolioConfigBuilder<SetUseMarkXrates<S>>
where S::UseMarkXrates: IsUnset,

Optional (Some / Option setters). Default: false.

The type of exchange rates used for portfolio calculations. If false (default), uses quote prices. If true, uses mark prices.

pub fn maybe_use_mark_xrates( self, value: Option<bool>, ) -> PortfolioConfigBuilder<SetUseMarkXrates<S>>
where S::UseMarkXrates: IsUnset,

Optional (Some / Option setters). Default: false.

The type of exchange rates used for portfolio calculations. If false (default), uses quote prices. If true, uses mark prices.

pub fn bar_updates( self, value: bool, ) -> PortfolioConfigBuilder<SetBarUpdates<S>>
where S::BarUpdates: IsUnset,

Optional (Some / Option setters). Default: true.

If external bars should be considered for updating unrealized PnLs.

pub fn maybe_bar_updates( self, value: Option<bool>, ) -> PortfolioConfigBuilder<SetBarUpdates<S>>
where S::BarUpdates: IsUnset,

Optional (Some / Option setters). Default: true.

If external bars should be considered for updating unrealized PnLs.

pub fn convert_to_account_base_currency( self, value: bool, ) -> PortfolioConfigBuilder<SetConvertToAccountBaseCurrency<S>>
where S::ConvertToAccountBaseCurrency: IsUnset,

Optional (Some / Option setters). Default: true.

If calculations should be converted into each account’s base currency. This setting is only effective for accounts with a specified base currency.

pub fn maybe_convert_to_account_base_currency( self, value: Option<bool>, ) -> PortfolioConfigBuilder<SetConvertToAccountBaseCurrency<S>>
where S::ConvertToAccountBaseCurrency: IsUnset,

Optional (Some / Option setters). Default: true.

If calculations should be converted into each account’s base currency. This setting is only effective for accounts with a specified base currency.

pub fn min_account_state_logging_interval_ms( self, value: u64, ) -> PortfolioConfigBuilder<SetMinAccountStateLoggingIntervalMs<S>>
where S::MinAccountStateLoggingIntervalMs: IsUnset,

Optional (Some / Option setters). The minimum interval (milliseconds) between logging account state events for the same account. When set, account state updates will only be logged if this much time has passed since the last log. Useful for HFT deployments to prevent excessive logging when account states change rapidly.

pub fn maybe_min_account_state_logging_interval_ms( self, value: Option<u64>, ) -> PortfolioConfigBuilder<SetMinAccountStateLoggingIntervalMs<S>>
where S::MinAccountStateLoggingIntervalMs: IsUnset,

Optional (Some / Option setters). The minimum interval (milliseconds) between logging account state events for the same account. When set, account state updates will only be logged if this much time has passed since the last log. Useful for HFT deployments to prevent excessive logging when account states change rapidly.

pub fn debug(self, value: bool) -> PortfolioConfigBuilder<SetDebug<S>>
where S::Debug: IsUnset,

Optional (Some / Option setters). Default: false.

If debug mode is active (will provide extra debug logging).

pub fn maybe_debug( self, value: Option<bool>, ) -> PortfolioConfigBuilder<SetDebug<S>>
where S::Debug: IsUnset,

Optional (Some / Option setters). Default: false.

If debug mode is active (will provide extra debug logging).